Struct Id
pub struct Id(NonZero<u64>);Expand description
An opaque ID that uniquely identifies a runtime relative to all other currently running runtimes.
Notes
- Runtime IDs are unique relative to other currently running runtimes. When a runtime completes, the same ID may be used for another runtime.
- Runtime IDs are not sequential, and do not indicate the order in which runtimes are started or any other data.
- The runtime ID of the currently running task can be obtained from the Handle.
Examples
use tokio::runtime::Handle;
#[tokio::main(flavor = "multi_thread", worker_threads = 4)]
async fn main() {
println!("Current runtime id: {}", Handle::current().id());
}Tuple Fields
0: NonZero<u64>Trait Implementations
impl Copy for Id
impl Eq for Id
impl StructuralPartialEq for Id